// CodePagesDlg.h
// (c) 2003-2005 exeal

#ifndef _CODE_PAGES_DLG_H_
#define _CODE_PAGES_DLG_H_
#include "resource.h"
#include "../Manah/Dialog.h"
#include "Ascension\Encodings\Encoder.h"


namespace Alpha {
	///	[R[hy[W̑I] _CAO
	class CCodePagesDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_CODEPAGES> {
		// RXgN^
	public:
		CCodePagesDlg(bool bForReading) : m_bForReading(bForReading) {}

		// f[^o
	public:
		Ascension::Encodings::CodePage	m_codePage;	// IꂽR[hy[W
	private:
		const bool	m_bForReading;

		// bZ[Wnh
	protected:
		virtual	bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
		virtual void	OnOK();													// IDOK
	};
}

#endif /* _CODE_PAGES_DLG_H_ */

/* [EOF] */